"""This module contains the resolver for the customer field in the subscription and process types."""

import strawberry
from orchestrator.graphql.schemas.customer import CustomerType
from orchestrator.graphql.schemas.process import ProcessType
from orchestrator.graphql.schemas.subscription import SubscriptionInterface
from orchestrator.graphql.utils.override_class import override_class

from gso.services.partners import get_partner_by_id


async def resolve_customer(root: CustomerType) -> CustomerType:
    """Resolve the customer field for a subscription or process."""
    partner = get_partner_by_id(root.customer_id)

    return CustomerType(
        customer_id=partner.partner_id,
        fullname=partner.name,
        shortcode=partner.email,
    )


customer_field = strawberry.field(
    resolver=resolve_customer,
    description="Returns customer of a subscription",
)
customer_field.name = "customer"  # type: ignore[attr-defined]

override_class(ProcessType, [customer_field])  # type: ignore[list-item]
custom_subscription_interface = override_class(SubscriptionInterface, [customer_field])  # type: ignore[list-item]
